#load libraries, some for plots and tables are also being loaded
library(caret)
library(coin)
library(effsize)
library(ggplot2)
library(ggpubr)
library(ggthemes)
library(hrbrthemes)
library(lmerTest)
library(MuMIn)
library(readxl)
library(reshape2)
library(Rmisc)
library(stargazer)
library(svglite)
library(tidyverse)
library(uwIntroStats)
library(viridis)
library(xlsx)
require(lme4)

#load data and discard NA's
my_data <- read_excel("your_data.xls", na = "---")

#filter data for pathological hemisphere, e.g. if you structured your data with 0s (no tumor) for healthy and 1s (with tumor) for pathological hemispheres
my_data$patho=as.factor(my_data$patho)
levels(my_data$patho)<- c("Healthy hemisphere", "Pathologic hemisphere")

#my_data2 <- read_excel("your_data.xls", na = "---")
my_data2$Hemispheres=as.factor(my_data2$Hemispheres)
levels(my_data2$Hemispheres)<- c("Healthy hemispheres", "Pathologic hemispheres")

#mixed effects model (MEM) for along tract statistical analysis, for FA, ADC and FD
fa_data <- my_data2 %>% 
  filter(measure=="FA")
view(fa_data)
m.1 <- lmer(value ~ Hemispheres+(1|Subj), data = fa_data)
summary(m.1.1)
anova(m.1)
r.squaredGLMM(m.1)

adc_data <- my_data2 %>% 
  filter(measure=="ADC")
m.2 <- lmer(value ~ Hemispheres+ (1|Subj), data = adc_data)
summary(m.2)
anova(m.2)

fixel_data <- my_data2 %>% 
  filter(measure=="Fixel")
m.3 <- lmer(value ~ Hemispheres+ (1|Subj), data = fixel_data)
summary(m.3)
anova(m.3)

#ixed effects model (MEM) for along tract statistical analysis, for FA, ADC and FD on peritumoral segments
peritumor_data <- my_data %>% 
  filter(new_peri_tumor==1)

fa_data2 <- peritumor_data %>% 
  filter(measure=="FA")
m.4 <- lmer(value ~ Hemispheres+ (1|Subj), data = fa_data2)
summary(m.4)
anova(m.4)

adc_data2 <- peritumor_data %>% 
  filter(measure=="ADC")
m.5 <- lmer(value ~ Hemispheres+(1|Subj), data = adc_data2)
summary(m.5)
anova(m.5)

fixel_data2 <- peritumor_data %>% 
  filter(measure=="Fixel")
m.6 <- lmer(value ~ Hemispheres+ (1|Subj), data = fixel_data2)
r.squaredGLMM(m.6)
summary(m.6)
anova(m.6)

#subject specific mixed effects model (MEM) for along tract statistical analysis
sX_fa_data <- my_data %>% 
  filter(Subj=="X") %>% 
  filter(measure=="FA") 
m.10 <- lmer(value ~ Hemispheres+(1|position), data = s110_fa_data)
summary(m.10)
anova(m.10)

sX_adc_data <- my_data %>% 
  filter(Subj=="X") %>% 
  filter(measure=="ADC")
m.11 <- lmer(value ~ Hemispheres+(1|position), data = s110_adc_data)
summary(m.11)
anova(m.11)

sX_fixel_data <- my_data %>% 
  filter(Subj=="X") %>% 
  filter(measure=="Fixel")
m.12 <- lmer(value ~ Hemispheres+(1|position), data = s110_fixel_data)
summary(m.12)
anova(m.12)

peri_sX_fa_data <- my_data2 %>% 
  filter(Subj=="X") %>% 
  filter(measure=="FA") %>% 
  filter(new_peri_tumor==1)
m.13 <- lmer(value ~ Hemispheres+(1|position), data = peri_s110_fa_data)
summary(m.13)
anova(m.13)

peri_sX_adc_data <- my_data2 %>% 
  filter(Subj=="X") %>% 
  filter(measure=="ADC") %>% 
  filter(new_peri_tumor==1)
m.14 <- lmer(value ~ Hemispheres+(1|position), data = peri_s110_adc_data)
summary(m.14)
anova(m.14)

peri_sX_fixel_data <- my_data2 %>% 
  filter(Subj=="X") %>% 
  filter(measure=="Fixel") %>% 
  filter(new_peri_tumor==1)
m.15 <- lmer(value ~ Hemispheres+(1|position), data = peri_s110_fixel_data)
summary(m.15)
anova(m.15)

#calculate sensitivity and specificity
#loop to calculate ADC p-values
f <- -1
p_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_adc_tms_hand_l_norm_resampled_100.txt",sep="")
  filename2 <- paste("S",s,"_adc_tms_hand_r_norm_resampled_100.txt",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      p_value <- wilcox.test(data.matrix(dat1[i]),data.matrix(dat2[i]),paired = F)$p.value
      p_list[f*100+i]<-p_value
    }
  }
}
write.csv(p_list<0.0005, file = "my_data.csv")

#loop to calculate FA p-values
f <- -1
p_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_fa_tms_hand_l_norm_resampled_100.csv",sep="")
  filename2 <- paste("S",s,"_fa_tms_hand_r_norm_resampled_100.csv",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      p_value <- wilcox.test(data.matrix(dat1[i]),data.matrix(dat2[i]),paired = F)$p.value
      p_list[f*100+i]<-p_value
    }
  }
}
write.csv(p_list<0.0005, file = "my_data.csv")

#loop to calculate fixel p-value
f <- -1
p_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_l_max.csv",sep="")
  filename2 <- paste("S",s,"_r_max.csv",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      p_value <- wilcox.test(data.matrix(dat1[i]),data.matrix(dat2[i]),paired = F)$p.value
      p_list[f*100+i]<-p_value
    }
  }
}
write.csv(p_list<0.0005, file = "my_data.csv")

#change TRUE to 1 and FALSE to 0
cols <- sapply(SC, is.logical)
SC[,cols] <- lapply(SC[,cols], as.numeric)
view(SC)

wilcox.test(data.matrix(dat1[73]),data.matrix(dat2[73]),paired = T)

mydf <- cbind(data.matrix(dat1[1]),data.matrix(dat2[1]))
View(dat1[1])
nrow(data.matrix(dat1[2]))
wilcox.test(data.matrix(dat1[3]),data.matrix(dat2[3]))
wil <- wilcoxon(data.matrix(dat1[3]),data.matrix(dat2[3]))

view(data.matrix(dat1[73]))
view(data.matrix(dat2[73]))
median(data.matrix(dat1[1]))-median(data.matrix(dat2[1]))

clif <-cliff.delta(data.matrix(dat1[3]),data.matrix(dat2[3]),return.dm=TRUE)$magnitude
clif2 <-cliff.delta(data.matrix(dat1[99]),data.matrix(dat2[99]),return.dm=TRUE)$magnitude

clif
clif2

#fixel
max_sens <- 1837/(1837+218)
max_sens
max_spec <- 845/(845+3586)
max_spec

#fa
table(my_data$new_peri_tumor,my_data$wilcoxon_fa)
max_sens <- 1829/(1829+240)
max_sens
max_spec <- 926/(926+3505)
max_spec

#adc
table(my_data$new_peri_tumor,my_data$wilcoxon_adc)
max_sens <- 1873/(1873+196)
max_sens
max_spec <- 846/(846+3585)
max_spec


#calculate Cliff's delta
#loop to calculate ADC p-values
f <- -1
delta_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_adc_tms_hand_l_norm_resampled_100.csv",sep="")
  filename2 <- paste("S",s,"_adc_tms_hand_r_norm_resampled_100.csv",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      clif <-cliff.delta(data.matrix(dat1[i]),data.matrix(dat2[i]),return.dm=TRUE)$magnitude
      delta_list[f*100+i]<-clif
    }
  }
}
view(p_list)

delta_list_adc <- delta_list
write.csv(delta_list_adc>3.5, file = "Delta_l.csv")
table(my_data$new_peri_tumor,my_data$delta_adc_l)
adc_sens<-1303/(1303+766)
adc_sens
adc_spec<-3009/(3009+1422)
adc_spec

#loop to calculate FA p-values
f <- -1
delta_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_fa_tms_hand_l_norm_resampled_100.csv",sep="")
  filename2 <- paste("S",s,"_fa_tms_hand_r_norm_resampled_100.csv",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      clif <-cliff.delta(data.matrix(dat1[i]),data.matrix(dat2[i]),return.dm=TRUE)$magnitude
      delta_list[f*100+i]<-clif
    }
  }
}

view(p_list)
delta_list_fa <- delta_list
write.csv(delta_list_fa>3.5, file = "Delta_l.csv")
table(my_data$new_peri_tumor,my_data$delta_fa_l)
adc_sens<-1152/(1252+918)
adc_sens
adc_spec<-3283/(3283+1148)
adc_spec

#loop for calculate Fixel p-values
f <- -1
delta_list<- rep(0,6500)
for (s in 1:250){
  filename1 <- paste("S",s,"_l_max.csv",sep="")
  filename2 <- paste("S",s,"_r_max.csv",sep="")
  if (file.exists(filename1)){
    dat1<- read.table(file = filename1, header = FALSE,fill = TRUE)
    dat2<- read.table(file = filename2, header = FALSE,fill = TRUE)
    f <- f+1
    for (i in 1:ncol(dat1)) {
      clif <-cliff.delta(data.matrix(dat1[i]),data.matrix(dat2[i]),return.dm=TRUE)$magnitude
      delta_list[f*100+i]<-clif
    }
  }
}

view(p_list)
delta_list_fixel <- delta_list
write.csv(delta_list_fixel>3.5, file = "Delta_l.csv")

table(my_data$new_peri_tumor,my_data$delta_max_l)
adc_sens<-670/(670+1399)
adc_sens
adc_spec<-3376/(3376+1055)
adc_spec